@@ -29,9 +29,7 @@
 #include <QVBoxLayout>
 #include <QLabel>
 
-namespace KPIMTextEdit
-{
-
+namespace KPIMTextEdit {
 class InsertHtmlDialogPrivate
 {
 public:
@@ -44,6 +42,7 @@ public:
         QLabel *label = new QLabel(i18n("Insert HTML tags and texts:"));
         lay->addWidget(label);
         editor = new InsertHtmlEditor;
+        editor->setSpellCheckingSupport(false);
         KPIMTextEdit::PlainTextEditorWidget *editorWidget = new KPIMTextEdit::PlainTextEditorWidget(editor);
         lay->addWidget(editorWidget);
         label = new QLabel(i18n("Example: <i> Hello word </i>"));
@@ -79,7 +78,8 @@ void InsertHtmlDialogPrivate::_k_slotTextChanged()
 }
 
 InsertHtmlDialog::InsertHtmlDialog(QWidget *parent)
-    : QDialog(parent), d(new InsertHtmlDialogPrivate(this))
+    : QDialog(parent)
+    , d(new InsertHtmlDialogPrivate(this))
 {
 }
 
@@ -88,12 +88,15 @@ InsertHtmlDialog::~InsertHtmlDialog()
     delete d;
 }
 
+void InsertHtmlDialog::setSelectedText(const QString &str)
+{
+    d->editor->setPlainText(str);
+}
+
 QString InsertHtmlDialog::html() const
 {
     return d->editor->toPlainText();
 }
-
 }
 
 #include "moc_inserthtmldialog.cpp"
-
