@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -26,16 +26,14 @@
 #include <QDialog>
 #include <QUrl>
 
-namespace KPIMTextEdit
-{
-
+namespace KPIMTextEdit {
 class InsertImageDialogPrivate;
 
 class KPIMTEXTEDIT_EXPORT InsertImageDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit InsertImageDialog(QWidget *parent = Q_NULLPTR);
+    explicit InsertImageDialog(QWidget *parent = nullptr);
     ~InsertImageDialog();
 
     int imageWidth() const;
@@ -54,7 +52,6 @@ private:
     InsertImageDialogPrivate *const d;
     Q_PRIVATE_SLOT(d, void _k_slotEnabledButtonChanged(bool))
 };
-
 }
 
 #endif // KPIMTEXTEDIT_INSERTIMAGEDIALOG_H
