@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,15 +23,13 @@
 #include "kpimtextedit_export.h"
 
 #include <Sonnet/Highlighter>
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class Rule;
 }
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class PlainTextEditor;
-class KPIMTEXTEDIT_EXPORT PlainTextSyntaxSpellCheckingHighlighter: public Sonnet::Highlighter
+class KPIMTEXTEDIT_EXPORT PlainTextSyntaxSpellCheckingHighlighter : public Sonnet::Highlighter
 {
 public:
     explicit PlainTextSyntaxSpellCheckingHighlighter(PlainTextEditor *plainText, const QColor &misspelledColor = Qt::red);
@@ -42,7 +40,7 @@ public:
     /**
      * Reimplemented to highlight quote blocks.
      */
-    void highlightBlock(const QString &text) Q_DECL_OVERRIDE;
+    void highlightBlock(const QString &text) override;
 
     void setSyntaxHighlighterRules(const QVector<KPIMTextEdit::Rule> &rule);
 protected:
@@ -53,13 +51,13 @@ protected:
      * @param start the beginning of text
      * @param count the amount of characters to set
      */
-    void unsetMisspelled(int start, int count) Q_DECL_OVERRIDE;
+    void unsetMisspelled(int start, int count) override;
 
     /**
      * Reimplemented to set the color of the misspelled word to a color
      * defined by setQuoteColor().
      */
-    void setMisspelled(int start, int count) Q_DECL_OVERRIDE;
+    void setMisspelled(int start, int count) override;
 
     virtual bool spellCheckBlock(const QString &text);
 private:
