@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,9 +27,7 @@
 #include <QtTextToSpeech/QTextToSpeech>
 #endif
 
-namespace KPIMTextEdit
-{
-
+namespace KPIMTextEdit {
 class TextToSpeechPrivate
 {
 public:
@@ -51,7 +49,7 @@ Q_GLOBAL_STATIC(TextToSpeechPrivate, sInstance)
 TextToSpeech::TextToSpeech(QObject *parent)
     : QObject(parent)
 #if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
-    , mTextToSpeech(Q_NULLPTR)
+    , mTextToSpeech(nullptr)
 #endif
 {
     reloadSettings();
@@ -59,7 +57,6 @@ TextToSpeech::TextToSpeech(QObject *parent)
 
 TextToSpeech::~TextToSpeech()
 {
-
 }
 
 void TextToSpeech::reloadSettings()
@@ -116,7 +113,7 @@ void TextToSpeech::slotStateChanged()
 bool TextToSpeech::isReady() const
 {
 #if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
-    return (mTextToSpeech->state() != QTextToSpeech::BackendError);
+    return mTextToSpeech->state() != QTextToSpeech::BackendError;
 #else
     return false;
 #endif
@@ -129,7 +126,6 @@ void TextToSpeech::say(const QString &text)
 #else
     Q_UNUSED(text);
 #endif
-
 }
 
 void TextToSpeech::stop()
@@ -202,7 +198,9 @@ QStringList TextToSpeech::availableVoices() const
 {
     QStringList lst;
 #if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
-    Q_FOREACH (const QVoice &voice, mTextToSpeech->availableVoices()) {
+    const QVector<QVoice> voices = mTextToSpeech->availableVoices();
+    lst.reserve(voices.count());
+    for (const QVoice &voice : voices) {
         lst << voice.name();
     }
 #endif
@@ -235,5 +233,4 @@ QLocale TextToSpeech::locale() const
     return QLocale();
 #endif
 }
-
 }
