@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,21 +21,19 @@
 #define TEXTTOSPEECHCONFIGDIALOG_H
 
 #include <QDialog>
-#include "kpimtextedit_export.h"
-namespace KPIMTextEdit
-{
+#include "kpimtextedit_private_export.h"
+namespace KPIMTextEdit {
 class TextToSpeechConfigWidget;
-class KPIMTEXTEDIT_EXPORT TextToSpeechConfigDialog : public QDialog
+class KPIMTEXTEDIT_TESTS_EXPORT TextToSpeechConfigDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit TextToSpeechConfigDialog(QWidget *parent = nullptr);
     ~TextToSpeechConfigDialog();
 
-private Q_SLOTS:
-    void slotAccepted();
-
 private:
+    void slotAccepted();
+    void slotRestoreDefaults();
     void readConfig();
     void writeConfig();
     KPIMTextEdit::TextToSpeechConfigWidget *mTextToSpeechConfigWidget;
@@ -43,4 +41,3 @@ private:
 }
 
 #endif // TEXTTOSPEECHCONFIGDIALOG_H
-
