@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,8 +26,7 @@
 #if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
 class QTextToSpeech;
 #endif
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class KPIMTEXTEDIT_EXPORT TextToSpeechConfigInterface : public AbstractTextToSpeechConfigInterface
 {
     Q_OBJECT
@@ -35,12 +34,12 @@ public:
     explicit TextToSpeechConfigInterface(QObject *parent = nullptr);
     ~TextToSpeechConfigInterface();
 
-    QVector<QLocale> availableLocales() const Q_DECL_OVERRIDE;
-    QLocale locale() const Q_DECL_OVERRIDE;
+    QVector<QLocale> availableLocales() const override;
+    QLocale locale() const override;
 
-    QStringList availableEngines() const Q_DECL_OVERRIDE;
-    QStringList availableVoices() const Q_DECL_OVERRIDE;
-    void setEngine(const QString &engineName) Q_DECL_OVERRIDE;
+    QStringList availableEngines() const override;
+    QStringList availableVoices() const override;
+    void setEngine(const QString &engineName) override;
 #if KPIMTEXTEDIT_HAVE_TEXTTOSPEECH
     QTextToSpeech *mTextToSpeech;
 #endif
@@ -48,4 +47,3 @@ public:
 }
 
 #endif // TEXTTOSPEECHCONFIGINTERFACE_H
-
