@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,14 +28,14 @@ public:
     TextToSpeechInterfacePrivate(TextToSpeechWidget *textToSpeechWidget)
         : mTextToSpeechWidget(textToSpeechWidget)
     {
-
     }
+
     TextToSpeechWidget *mTextToSpeechWidget;
 };
 
 TextToSpeechInterface::TextToSpeechInterface(TextToSpeechWidget *textToSpeechWidget, QObject *parent)
-    : AbstractTextToSpeechInterface(parent),
-      d(new KPIMTextEdit::TextToSpeechInterfacePrivate(textToSpeechWidget))
+    : AbstractTextToSpeechInterface(parent)
+    , d(new KPIMTextEdit::TextToSpeechInterfacePrivate(textToSpeechWidget))
 {
     KPIMTextEdit::TextToSpeech::self(); //init
     connect(d->mTextToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::stateChanged, this, &TextToSpeechInterface::stateChanged);
