@@ -34,15 +34,14 @@ class KPIMTextEdit::TextToSpeechWidgetPrivate
 {
 public:
     TextToSpeechWidgetPrivate()
-        : mNeedToHide(false),
-          mStopButton(nullptr),
-          mPlayPauseButton(nullptr),
-          mConfigureButton(nullptr),
-          mTextToSpeechInterface(nullptr),
-          mTextToSpeechActions(nullptr),
-          mVolume(nullptr)
+        : mNeedToHide(false)
+        , mStopButton(nullptr)
+        , mPlayPauseButton(nullptr)
+        , mConfigureButton(nullptr)
+        , mTextToSpeechInterface(nullptr)
+        , mTextToSpeechActions(nullptr)
+        , mVolume(nullptr)
     {
-
     }
 
     bool mNeedToHide;
@@ -56,8 +55,8 @@ public:
 };
 
 TextToSpeechWidget::TextToSpeechWidget(QWidget *parent)
-    : QWidget(parent),
-      d(new KPIMTextEdit::TextToSpeechWidgetPrivate)
+    : QWidget(parent)
+    , d(new KPIMTextEdit::TextToSpeechWidgetPrivate)
 {
     QHBoxLayout *hbox = new QHBoxLayout;
     setLayout(hbox);
@@ -80,6 +79,7 @@ TextToSpeechWidget::TextToSpeechWidget(QWidget *parent)
     d->mVolume->setOrientation(Qt::Horizontal);
     d->mVolume->setObjectName(QStringLiteral("volumeslider"));
     d->mVolume->setRange(0, 100);
+    d->mVolume->setTickPosition(QSlider::TicksBelow);
     connect(d->mVolume, &QSlider::valueChanged, this, &TextToSpeechWidget::slotVolumeChanged);
     hbox->addWidget(d->mVolume);
 
@@ -100,7 +100,7 @@ TextToSpeechWidget::TextToSpeechWidget(QWidget *parent)
     connect(d->mConfigureButton, &QToolButton::clicked, this, &TextToSpeechWidget::slotConfigure);
     hbox->addWidget(d->mConfigureButton);
 
-    d->mTextToSpeechInterface = new TextToSpeechInterface(this, this);
+    setTextToSpeechInterface(new TextToSpeechInterface(this, this));
     hide();
 }
 
@@ -150,7 +150,7 @@ TextToSpeechWidget::State TextToSpeechWidget::state() const
 void TextToSpeechWidget::slotStateChanged(KPIMTextEdit::TextToSpeech::State state)
 {
     switch (state) {
-    case KPIMTextEdit::TextToSpeech::Ready: {
+    case KPIMTextEdit::TextToSpeech::Ready:
         if (state == KPIMTextEdit::TextToSpeech::Ready) {
             d->mTextToSpeechActions->setState(TextToSpeechWidget::Stop);
             if (d->mConfigDialog) {
@@ -160,7 +160,6 @@ void TextToSpeechWidget::slotStateChanged(KPIMTextEdit::TextToSpeech::State stat
             }
         }
         break;
-    }
     default:
         //TODO
         break;
@@ -176,4 +175,9 @@ void TextToSpeechWidget::setTextToSpeechInterface(AbstractTextToSpeechInterface
 {
     delete d->mTextToSpeechInterface;
     d->mTextToSpeechInterface = interface;
+    //Update volume value
+    if (d->mTextToSpeechInterface) {
+        d->mTextToSpeechInterface->reloadSettings();
+        d->mVolume->setValue(interface->volume());
+    }
 }
